@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.c,v 1.53 2003/12/15 15:20:07 fuyu Exp $
+ * $Id: bbs_thread_ui.c,v 1.55 2003/12/16 19:47:43 fuyu Exp $
  */
 
 #include "config.h"
@@ -52,7 +52,7 @@
 #include <string.h>
 
 
-#define DEBUG_POPUP	0
+#define DEBUG_POPUP		0
 
 typedef struct _PopupContext PopupContext;
 
@@ -117,6 +117,12 @@ static guint link_field_id;
 /* Ǹ˥ơСɽåФmessage ID */
 static guint message_id;
 
+/*
+ * ơС˥Фͥåȥξ֤ɽ뤿
+ * context ID
+ */
+guint thread_netstat_id;
+
 
 #define THREAD_INFO_LOCK				\
   if (pthread_mutex_lock(&thread_info_lock) != 0)	\
@@ -531,6 +537,8 @@ initialize_thread_ui(OchushaApplication *application)
 
   link_field_id = gtk_statusbar_get_context_id(application->statusbar,
 					       "response-link-field");
+  thread_netstat_id = gtk_statusbar_get_context_id(application->statusbar,
+						   "thread-netstat");
 
   dummy_widget = bbs_thread_view_new(NULL);
   dummy_view = BBS_THREAD_VIEW(dummy_widget);
@@ -643,9 +651,6 @@ specify_thread_view_point(OchushaBBSThread *thread, PanedNotebook *board_view,
   BBS_THREAD_UI_LOCK
   {
     int offset;
-    /*
-     * ȡɽϤĤˤʤ
-     */
     info->res_num = res_num;
     if (info->rendering_done && info->last_read != NULL
 	&& res_num < info->offsets_length
@@ -710,7 +715,9 @@ open_bbs_thread(OchushaApplication *application, OchushaBBSThread *thread,
 
     if (buffer == NULL)
       {
+#if DEBUG_NETWORK_MOST
 	fprintf(stderr, "Couldn't access network!\n");
+#endif
 	G_FREE(job_args);
 	G_FREE(job);
 	gtk_object_sink(GTK_OBJECT(thread_view));
@@ -1214,6 +1221,12 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
   OchushaAsyncBuffer *buffer = job_args->buffer;
   gchar default_text_buffer[DEFAULT_BUFFER_SIZE];
   iconv_helper *helper = ochusha_bbs_thread_get_response_iconv_helper(thread);
+  gboolean a_bone_by_name;
+  gchar *a_bone_by_name_pattern;
+  gboolean a_bone_by_id;
+  gchar *a_bone_by_id_pattern;
+  gboolean a_bone_by_content;
+  gchar *a_bone_by_content_pattern;
   RendererContext context =
     {
       {
@@ -1258,13 +1271,6 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
       						/* regex_t */
   };
 
-  gboolean a_bone_by_name;
-  gchar *a_bone_by_name_pattern;
-  gboolean a_bone_by_id;
-  gchar *a_bone_by_id_pattern;
-  gboolean a_bone_by_content;
-  gchar *a_bone_by_content_pattern;
-
   /* "\357\274\214\343\200\201\357\274\235"  "" UTF-8ɽ */
   if (regcomp(&context.comma_separated_link_pattern,
 	      "^[,=\357\274\214\343\200\201\357\274\235][ ]*([1-9][0-9]*)(-[1-9][0-9]*)?",
@@ -1428,6 +1434,33 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
 #if DEBUG_GUI
       fprintf(stderr, "create mark at the tail response.\n");
 #endif
+      snprintf(default_text_buffer, DEFAULT_BUFFER_SIZE,
+	       _("Updating thread %s@%s board"),
+	       thread->title, thread->board->name);
+
+      gdk_threads_enter();
+      if (info->message_id != 0)
+	gtk_statusbar_remove(application->statusbar, thread_netstat_id,
+			     info->message_id);
+      info->message_id
+	= gtk_statusbar_push(application->statusbar, thread_netstat_id,
+			     default_text_buffer);
+      gdk_threads_leave();
+    }
+  else
+    {
+      snprintf(default_text_buffer, DEFAULT_BUFFER_SIZE,
+	       _("Getting thread %s@%s board"),
+	       thread->title, thread->board->name);
+
+      gdk_threads_enter();
+      if (info->message_id != 0)
+	gtk_statusbar_remove(application->statusbar, thread_netstat_id,
+			     info->message_id);
+      info->message_id
+	= gtk_statusbar_push(application->statusbar, thread_netstat_id,
+			     default_text_buffer);
+      gdk_threads_leave();
     }
 
   ochusha_bbs_thread_parse_responses(thread, buffer,
@@ -1465,6 +1498,15 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
 #endif
   g_object_unref(G_OBJECT(buffer));
 
+  gdk_threads_enter();
+  if (info->message_id != 0)
+    {
+      gtk_statusbar_remove(application->statusbar, thread_netstat_id,
+			   info->message_id);
+      info->message_id = 0;
+    }
+  gdk_threads_leave();
+
   BBS_THREAD_UI_LOCK
   {
     info->rendering_done = TRUE;
@@ -1532,9 +1574,8 @@ start_thread_rendering(OchushaBBSThread *thread, const gchar *title,
 
   if (info->last_read != NULL)
     {
-      /* save_initial_thread_view_position(...)򤷤ʤȡ
-       * 碌ƥ뤷ƤޤȤΤǡŪ
-       * ƬŽդ롣
+      /* bbs_thread_view_scroll_to_mark(...)ϥ뤵뤿
+       * ǤϤʤŪ˥ƬŽդ뤿˸Ƥ֡
        */
       bbs_thread_view_scroll_to_mark(view, info->last_read);
     }
@@ -2783,7 +2824,9 @@ refresh_thread(OchushaApplication *application, GtkWidget *widget,
 
     if (buffer == NULL)
       {
+#if DEBUG_NETWORK_MOST
 	fprintf(stderr, "Couldn't access network!\n");
+#endif
 	BBS_THREAD_UI_UNLOCK;
 	if (job != NULL)
 	  G_FREE(job);
