@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.h,v 1.14 2003/12/14 19:04:36 fuyu Exp $
+ * $Id: bbs_thread_ui.h,v 1.15 2003/12/16 14:50:33 fuyu Exp $
  */
 
 #ifndef _BBSTHREAD_UI_H_
@@ -78,6 +78,9 @@ typedef struct _BBSThreadGUIInfo
   /* ɸɽ֤ޤǳμ¤()뤵뤿idleؿ */
   guint scroller_id;
 
+  /* ξ֤ɽstatusbarΥåID */
+  guint message_id;
+
   /* ġΥ쥹GtkTextBuffer⥪եå */
   guint *offsets;
   guint offsets_length;
