@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_ui.c,v 1.36 2003/12/12 21:43:52 fuyu Exp $
+ * $Id: boardlist_ui.c,v 1.38 2003/12/16 18:00:54 fuyu Exp $
  */
 
 #include "config.h"
@@ -83,6 +83,8 @@ static void kill_category_cb(BoardlistView *view,
 			     OchushaApplication *application);
 static void kill_board_cb(BoardlistView *view, OchushaBulletinBoard *board,
 			  OchushaApplication *application);
+static void copy_board_url_cb(BoardlistView *view, OchushaBulletinBoard *board,
+			      OchushaApplication *application);
 
 static void boardlist_read_category_element_cb(OchushaBBSTable *table,
 					       OchushaBoardCategory *category,
@@ -252,6 +254,8 @@ initialize_boardlist(OchushaApplication *application)
 		   G_CALLBACK(kill_category_cb), application);
   g_signal_connect(G_OBJECT(application->boardlist_view), "kill_board",
 		   G_CALLBACK(kill_board_cb), application);
+  g_signal_connect(G_OBJECT(application->boardlist_view), "copy_board_url",
+		   G_CALLBACK(copy_board_url_cb), application);
 #if TRACE_MEMORY_USAGE
   g_signal_connect(G_OBJECT(application->boardlist_view), "destroy",
 		   G_CALLBACK(gtk_widget_destroyed),
@@ -962,6 +966,9 @@ item_view_required_cb(PanedNotebook *paned_notebook, gpointer item,
 }
 
 
+extern guint threadlist_netstat_id;
+
+
 static void
 item_view_being_closed_cb(PanedNotebook *paned_notebook,
 			  OchushaBulletinBoard *board,
@@ -970,6 +977,8 @@ item_view_being_closed_cb(PanedNotebook *paned_notebook,
 {
   OchushaAsyncBuffer *buffer
     = snatch_threadlist_source_buffer_for_board(board, application);
+  BulletinBoardGUIInfo *info
+    = ensure_bulletin_board_info(board, application);
 
   /*
    * MEMO: ɽƤ륦åȤºݤ˼ΤƤ륿ߥ
@@ -1016,6 +1025,14 @@ item_view_being_closed_cb(PanedNotebook *paned_notebook,
 
   if (buffer != NULL)
     g_object_unref(G_OBJECT(buffer));
+
+  if (info->message_id != 0)
+    {
+      gtk_statusbar_remove(application->statusbar, threadlist_netstat_id,
+			   info->message_id);
+      info->message_id = 0;
+    }
+
   return;
 }
 
@@ -1131,6 +1148,9 @@ boardlist_read_board_element_cb(OchushaBBSTable *table,
 						       "last_name");
   info->last_mail = ochusha_utils_get_attribute_string(board_attributes,
 						       "last_mail");
+  if (!info->recover_mode)
+    info->recover_mode = ochusha_utils_get_attribute_boolean(board_attributes,
+							     "recover_mode");
 
   info->board_local_a_bone
     = ochusha_utils_get_attribute_boolean(board_attributes,
@@ -1214,6 +1234,8 @@ boardlist_write_board_element_cb(OchushaBBSTable *table,
   OUTPUT_BOARD_ATTRIBUTE_BOOLEAN(boardlist_xml, info, enable_filter);
   OUTPUT_BOARD_ATTRIBUTE_STRING(boardlist_xml, info, last_name);
   OUTPUT_BOARD_ATTRIBUTE_STRING(boardlist_xml, info, last_mail);
+  if (info->recover_mode)
+    OUTPUT_BOARD_ATTRIBUTE_BOOLEAN(boardlist_xml, info, recover_mode);
 
   if (info->filter.rule != NULL)
     {
@@ -1250,12 +1272,22 @@ write_threadlist(gpointer data, gpointer user_data)
 }
 
 
+static OchushaBoardCategory *last_expanded_category = NULL;
+
+
 static void
 category_expanded_cb(BoardlistView *view, OchushaBoardCategory *category,
 		     OchushaApplication *application)
 {
   BoardCategoryGUIInfo *info = ensure_board_category_info(category);
   info->expanded = TRUE;
+  if (application->expand_only_one_category)
+    {
+      if (last_expanded_category != NULL && last_expanded_category != category)
+	boardlist_view_collapse_category(view, last_expanded_category);
+
+      last_expanded_category = category;
+    }
 }
 
 
@@ -1300,6 +1332,15 @@ kill_board_cb(BoardlistView *view, OchushaBulletinBoard *board,
 }
 
 
+static void
+copy_board_url_cb(BoardlistView *view, OchushaBulletinBoard *board,
+		  OchushaApplication *application)
+{
+  ochusha_clipboard_set_text(application,
+			     ochusha_bulletin_board_get_base_url(board));
+}
+
+
 static gboolean
 prepare_category(OchushaBoardCategory *category, gpointer user_data)
 {
@@ -1428,8 +1469,10 @@ setup_boardlist(OchushaApplication *application)
   boardlist_view_open(BOARDLIST_VIEW(application->boardlist_view),
 		      application->table->category_list,
 		      application->hide_hidden_boardlist_items);
-  g_slist_foreach(application->table->category_list,
-		  (GFunc)restore_expanded_state, application->boardlist_view);
+  if (!application->expand_only_one_category)
+    g_slist_foreach(application->table->category_list,
+		    (GFunc)restore_expanded_state,
+		    application->boardlist_view);
 
   gtk_widget_show_all(application->boardlist_view);
   gtk_widget_show_all(application->contents_window);
