@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bulletin_board_ui.c,v 1.71 2003/12/15 17:34:33 fuyu Exp $
+ * $Id: bulletin_board_ui.c,v 1.73 2003/12/16 18:00:54 fuyu Exp $
  */
 
 #include "config.h"
@@ -185,6 +185,9 @@ static guint title_popup_delay_id = 0;
 static GQuark board_info_id;
 static GQuark application_id;
 
+guint threadlist_netstat_id;		/* ¼privateġġ*/
+static guint writing_netstat_id;
+
 
 void
 prepare_board_ui_initialization(OchushaApplication *application)
@@ -236,6 +239,11 @@ initialize_board_ui(OchushaApplication *application)
   gtk_container_add(GTK_CONTAINER(title_popup_window), title_popup_label);
 
   application->thread_search_window = NULL;
+
+  threadlist_netstat_id = gtk_statusbar_get_context_id(application->statusbar,
+						       "threadlist-netstat");
+  writing_netstat_id = gtk_statusbar_get_context_id(application->statusbar,
+						    "writing-netstat");
 }
 
 
@@ -419,6 +427,7 @@ ensure_bulletin_board_info(OchushaBulletinBoard *board,
 	g_signal_connect(G_OBJECT(board), "threadlist_write_thread_element",
 			 G_CALLBACK(threadlist_write_thread_element_cb),
 			 application);
+	info->recover_mode = application->recover_mode;
       }
   }
   BOARD_INFO_UNLOCK;
@@ -1133,8 +1142,10 @@ show_threadlist(WorkerThread *employee, gpointer args)
   }
 #endif
 
-  if (board->thread_list == NULL)
-    ochusha_bulletin_board_read_threadlist_xml(board, &application->config);
+  /* ˽λʤäˤ٤ */
+  ochusha_bulletin_board_read_threadlist_xml(board, &application->config,
+					     info->recover_mode);
+  info->recover_mode = FALSE;
 
   THREAD_LIST_LOCK
   {
@@ -1155,6 +1166,19 @@ show_threadlist(WorkerThread *employee, gpointer args)
     }
 
   gdk_threads_enter();
+
+  if (job_args->increment_ignored)
+    {
+      gchar message[4096];
+      snprintf(message, 4096, _("Updating threadlist of %s board"),
+	       board->name);
+      if (info->message_id != 0)
+	gtk_statusbar_remove(application->statusbar, threadlist_netstat_id,
+			     info->message_id);
+      info->message_id
+	= gtk_statusbar_push(application->statusbar, threadlist_netstat_id,
+			     message);
+    }
   if (!threadlist_view_open(view))
     {
       gdk_threads_leave();
@@ -1190,6 +1214,16 @@ show_threadlist(WorkerThread *employee, gpointer args)
   fprintf(stderr, "* before unref: buffer->ref_count=%d\n",
 	  G_OBJECT(buffer)->ref_count);
 #endif
+
+  gdk_threads_enter();
+  if (info->message_id != 0)
+    {
+      gtk_statusbar_remove(application->statusbar, threadlist_netstat_id,
+			   info->message_id);
+      info->message_id = 0;
+    }
+  gdk_threads_leave();
+
   THREAD_LIST_LOCK
   {
     if (!info->redraw_required)
@@ -1202,7 +1236,7 @@ show_threadlist(WorkerThread *employee, gpointer args)
 	cb_args.number_of_threads = 0;
 	cb_args.last_thread = NULL;
 	cb_args.enable_filter = info->enable_filter;
-	cb_args.increment_ignored = TRUE;
+	cb_args.increment_ignored = FALSE;
 	goto redraw;
       }
   }
@@ -1562,6 +1596,9 @@ free_response_source_buffer(OchushaBBSThread *thread, gpointer unused)
 }
 
 
+extern guint thread_netstat_id;
+
+
 static void
 item_view_being_closed_cb(PanedNotebook *paned_notebook,
 			  OchushaBBSThread *thread, GtkWidget *item_view,
@@ -1639,6 +1676,13 @@ item_view_being_closed_cb(PanedNotebook *paned_notebook,
       g_source_remove(info->scroller_id);
       info->scroller_id = 0;
     }
+
+  if (info->message_id != 0)
+    {
+      gtk_statusbar_remove(application->statusbar, thread_netstat_id,
+			   info->message_id);
+      info->message_id = 0;
+    }
 }
 
 
@@ -1814,11 +1858,18 @@ background_write_response(WorkerThread *employee, gpointer job_args)
   WriteResponseJobArgs *args = (WriteResponseJobArgs *)job_args;
   OchushaBBSResponse response;
   gboolean result;
+  guint message_id;
+  gchar message[4096];
 
   response.name = args->name;
   response.mailto = args->mailto;
   response.content = args->message;
 
+  snprintf(message, 4096, _("Posting response to %s@%s board"),
+	   args->thread->title, args->thread->board->name);
+  message_id = gtk_statusbar_push(args->application->statusbar,
+				  writing_netstat_id, message);
+
   result = ochusha_bbs_thread_post_response(args->thread,
 					    args->application->broker,
 					    &response);
@@ -1834,6 +1885,12 @@ background_write_response(WorkerThread *employee, gpointer job_args)
       GtkWidget *notebook;
 
       gdk_threads_enter();
+      if (message_id != 0)
+	{
+	  gtk_statusbar_remove(args->application->statusbar,
+			       writing_netstat_id, message_id);
+	  message_id = 0;
+	}
       if (thread_info->last_name == NULL
 	  || strcmp(thread_info->last_name, response.name) != 0)
 	{
@@ -1903,7 +1960,20 @@ background_write_response(WorkerThread *employee, gpointer job_args)
     }
   else
     {
+      snprintf(message, 4096, _("Posting to %s@%s board failed."),
+	       args->thread->title, args->thread->board->name);
+
       gdk_threads_enter();
+      if (message_id != 0)
+	{
+	  gtk_statusbar_remove(args->application->statusbar,
+			       writing_netstat_id, message_id);
+	  message_id = 0;
+	}
+      message_id = gtk_statusbar_push(args->application->statusbar,
+				  writing_netstat_id, message);
+      g_object_set_data(G_OBJECT(args->dialog), "status_message",
+			(gpointer)message_id);
       ochusha_open_url(args->application,
 		       ochusha_bbs_thread_get_url_to_post_response(args->thread),
 		       FALSE, TRUE);
@@ -1931,6 +2001,14 @@ write_dialog_response_cb(GtkWidget *write_dialog, gint response_id,
 
   if (response_id != GTK_RESPONSE_OK)
     {
+      guint message_id = (guint)g_object_get_data(G_OBJECT(write_dialog),
+						  "status_message");
+      if (message_id != 0)
+	{
+	  gtk_statusbar_remove(application->statusbar,
+			       writing_netstat_id, message_id);
+	  g_object_set_data(G_OBJECT(write_dialog), "status_message", NULL);
+	}
       gtk_widget_destroy(write_dialog);
       return;
     }
