@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bulletin_board_ui.h,v 1.19 2003/12/12 21:43:52 fuyu Exp $
+ * $Id: bulletin_board_ui.h,v 1.21 2003/12/16 18:00:54 fuyu Exp $
  */
 
 #ifndef _BULLETIN_BOARD_UI_H_
@@ -63,6 +63,9 @@ typedef struct _BulletinBoardGUIInfo
   /* ᥤ򥹥ɽϤʸȤɽ뤫ɤĤΥǥե */
   ThreadViewMailtoMode show_mailto_mode;
 
+  /* ξ֤ɽstatusbarΥåID */
+  guint message_id;
+
   /* Ǹν񤭹߻̾ */
   gchar *last_name;
 
@@ -81,6 +84,7 @@ typedef struct _BulletinBoardGUIInfo
   gboolean a_bone_by_content;
   gchar *a_bone_by_content_pattern;
 
+  gboolean recover_mode;
 
   /* ե륿 */
   ThreadlistFilter filter;
