@@ -40,21 +40,21 @@ extern void ochusha_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
 
-/* VOID:POINTER,BOOLEAN (marshal.list:9) */
-extern void ochusha_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
-                                                   GValue       *return_value,
-                                                   guint         n_param_values,
-                                                   const GValue *param_values,
-                                                   gpointer      invocation_hint,
-                                                   gpointer      marshal_data);
+/* VOID:OBJECT,BOOLEAN (marshal.list:9) */
+extern void ochusha_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
+                                                  GValue       *return_value,
+                                                  guint         n_param_values,
+                                                  const GValue *param_values,
+                                                  gpointer      invocation_hint,
+                                                  gpointer      marshal_data);
 
-/* VOID:POINTER,POINTER (marshal.list:10) */
-extern void ochusha_marshal_VOID__POINTER_POINTER (GClosure     *closure,
-                                                   GValue       *return_value,
-                                                   guint         n_param_values,
-                                                   const GValue *param_values,
-                                                   gpointer      invocation_hint,
-                                                   gpointer      marshal_data);
+/* VOID:POINTER,OBJECT (marshal.list:10) */
+extern void ochusha_marshal_VOID__POINTER_OBJECT (GClosure     *closure,
+                                                  GValue       *return_value,
+                                                  guint         n_param_values,
+                                                  const GValue *param_values,
+                                                  gpointer      invocation_hint,
+                                                  gpointer      marshal_data);
 
 /* VOID:BOXED,POINTER,STRING (marshal.list:11) */
 extern void ochusha_marshal_VOID__BOXED_POINTER_STRING (GClosure     *closure,
