@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.c,v 1.46 2003/12/15 17:34:33 fuyu Exp $
+ * $Id: ochusha_ui.c,v 1.49 2003/12/16 19:47:43 fuyu Exp $
  */
 
 #include "config.h"
@@ -869,6 +869,7 @@ on_quit(gpointer data, guint action, GtkWidget *widget)
 
   finalize_boardlist(application);
 
+  application->shutdown_succeeded = TRUE;
   if (!ochusha_write_config_xml(&application->config,
 				write_optional_prefs, application))
     fprintf(stderr, "Couldn't write %s.\n", OCHUSHA_CONFIG_XML);
@@ -1045,16 +1046,21 @@ write_optional_prefs(FILE *file, gpointer user_data)
 
   OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application,
 				  hide_hidden_boardlist_items);
+  OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application,
+				  expand_only_one_category);
   OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application, hide_hidden_threads);
 
   OUTPUT_CONFIG_ATTRIBUTE_STRING(file, application, last_name);
   OUTPUT_CONFIG_ATTRIBUTE_STRING(file, application, last_mail);
+
+  OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application, shutdown_succeeded);
 }
 
 
 static void
 configure_application(OchushaApplication *application)
 {
+  gboolean succeeded;
   ochusha_read_config_xml(&application->config, read_optional_prefs,
 			  application);
   application->broker = ochusha_network_broker_new(&application->config);
@@ -1133,8 +1139,10 @@ configure_application(OchushaApplication *application)
 	= OCHUSHA_DEFAULT_SHOW_THREADLIST_ENTRY_WHEN_THREAD_SELECTED;
       application->hide_hidden_boardlist_items
 	= OCHUSHA_DEFAULT_HIDE_HIDDEN_BOARDLIST_ITEMS;
+      application->expand_only_one_category = FALSE;
       application->hide_hidden_threads
 	= OCHUSHA_DEFAULT_HIDE_HIDDEN_THREADS;
+      application->shutdown_succeeded = FALSE;
     }
 
   if (application->threadlist_view_contents == NULL)
@@ -1155,6 +1163,17 @@ configure_application(OchushaApplication *application)
   if (application->web_browser_template == NULL)
     application->web_browser_template
       = G_STRDUP(OCHUSHA_DEFAULT_WEB_BROWSER_TEMPLATE);
+
+  succeeded = application->shutdown_succeeded;
+  application->shutdown_succeeded = FALSE;
+  if (!ochusha_write_config_xml(&application->config,
+				write_optional_prefs, application))
+    fprintf(stderr, "Couldn't write %s.\n", OCHUSHA_CONFIG_XML);
+  application->shutdown_succeeded = succeeded;
+  if (!succeeded)
+    application->recover_mode = TRUE;
+  else
+    application->recover_mode = FALSE;
 }
 
 
@@ -1363,6 +1382,9 @@ read_optional_prefs(GHashTable *pref_attrs, gpointer user_data)
   application->hide_hidden_boardlist_items
     = ochusha_utils_get_attribute_boolean(pref_attrs,
 					  "hide_hidden_boardlist_items");
+  application->expand_only_one_category
+    = ochusha_utils_get_attribute_boolean(pref_attrs,
+					  "expand_only_one_category");
   application->hide_hidden_threads
     = ochusha_utils_get_attribute_boolean(pref_attrs, "hide_hidden_threads");
 
@@ -1370,6 +1392,8 @@ read_optional_prefs(GHashTable *pref_attrs, gpointer user_data)
 							      "last_name");
   application->last_mail = ochusha_utils_get_attribute_string(pref_attrs,
 							      "last_mail");
+  application->shutdown_succeeded
+    = ochusha_utils_get_attribute_boolean(pref_attrs, "shutdown_succeeded");
 }
 
 
@@ -1483,7 +1507,11 @@ access_failed_cb(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer,
 		 OchushaNetworkBrokerFailureReason reason_code,
 		 const gchar *reason, OchushaApplication *application)
 {
-  IconLabel *tab_label = g_object_get_qdata(G_OBJECT(buffer), tab_label_id);
+  IconLabel *tab_label;
+  if (buffer == NULL)
+    return TRUE;
+
+  tab_label = g_object_get_qdata(G_OBJECT(buffer), tab_label_id);
 
 #if DEBUG_GUI
   gchar *native_reason = g_locale_from_utf8(reason, -1, NULL, NULL, NULL);
@@ -1545,6 +1573,14 @@ preference_dialog_response_cb(GtkWidget *widget, gint response_id,
 	      }
 	  }
 
+	tmp_data = g_object_get_data(G_OBJECT(widget),
+				     "expand_only_one_category");
+	if (tmp_data != NULL)
+	  {
+	    application->expand_only_one_category
+	      = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(tmp_data));
+	  }
+
 	tmp_data = g_object_get_data(G_OBJECT(widget),
 				     "board_tab_enable_tooltips");
 	if (tmp_data != NULL)
@@ -1882,11 +1918,19 @@ build_ochusha_setting_frame(OchushaApplication *application,
   gtk_box_pack_start(GTK_BOX(outer_vbox), tmp_widget, FALSE, FALSE, 5);
   g_object_set_data(G_OBJECT(dialog), "default_open_in_tab", tmp_widget);
 
+  tmp_widget = gtk_check_button_new_with_label(_("Expand only one category at once."));
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tmp_widget),
+			       application->expand_only_one_category);
+  gtk_widget_show(tmp_widget);
+  gtk_box_pack_start(GTK_BOX(outer_vbox), tmp_widget, FALSE, FALSE, 5);
+  g_object_set_data(G_OBJECT(dialog), "expand_only_one_category",
+		    tmp_widget);
+
   tmp_widget = gtk_check_button_new_with_label(_("Enable Tooltips of Board Tab Label."));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tmp_widget),
 			       application->board_tab_enable_tooltips);
   gtk_widget_show(tmp_widget);
-  gtk_box_pack_start(GTK_BOX(outer_vbox), tmp_widget, FALSE, FALSE, 5);
+  gtk_box_pack_start(GTK_BOX(outer_vbox), tmp_widget, FALSE, FALSE, 0);
   g_object_set_data(G_OBJECT(dialog), "board_tab_enable_tooltips",
 		    tmp_widget);
 
@@ -1894,7 +1938,7 @@ build_ochusha_setting_frame(OchushaApplication *application,
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tmp_widget),
 			       application->board_tab_always_show);
   gtk_widget_show(tmp_widget);
-  gtk_box_pack_start(GTK_BOX(outer_vbox), tmp_widget, FALSE, FALSE, 5);
+  gtk_box_pack_start(GTK_BOX(outer_vbox), tmp_widget, FALSE, FALSE, 0);
   g_object_set_data(G_OBJECT(dialog), "board_tab_always_show", tmp_widget);
 
 #if 0
