@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.h,v 1.31 2003/12/15 17:34:34 fuyu Exp $
+ * $Id: ochusha_ui.h,v 1.34 2003/12/16 19:47:43 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_UI_H_
@@ -185,6 +185,7 @@ struct _OchushaApplication
   gboolean board_tab_enable_tooltips;
   gboolean board_tab_always_show;
   gboolean hide_hidden_boardlist_items;
+  gboolean expand_only_one_category;
 
 
   gint threadlist_pane_style;
@@ -247,6 +248,10 @@ struct _OchushaApplication
   /* Ǹν񤭹߻Υᥤ */
   gchar *last_mail;
 
+  /* ˽λɤ */
+  gboolean shutdown_succeeded;
+  gboolean recover_mode;
+
   OchushaConfig config;
 };
 
