@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: threadlist_filter.c,v 1.7 2003/11/23 22:04:09 fuyu Exp $
+ * $Id: threadlist_filter.c,v 1.8 2003/12/11 19:38:37 fuyu Exp $
  */
 
 #include "config.h"
@@ -122,6 +122,8 @@ static const gchar *hide_without_new_res;
 static const gchar *show_dat_dropped;
 static const gchar *hide_ignored;
 static const gchar *hide_hidden;
+static const gchar *show_good_title;
+static const gchar *hide_no_good_title;
 static const gchar *invalid_rule;
 
 
@@ -215,6 +217,8 @@ threadlist_filter_setting_class_init(ThreadlistFilterSettingClass *klass)
   show_dat_dropped = _("Show threads whose DAT was dropped");
   hide_ignored = _("Hide threads too much times ignored");
   hide_hidden = _("Hide hidden threads");
+  show_good_title = _("Show threads having good title");
+  hide_no_good_title = _("Hide threads having no good title");
   invalid_rule = _("Invalid rule");
 }
 
@@ -1001,6 +1005,22 @@ setup_models(ThreadlistFilterSetting *setting)
 	-1);
   setting->hide_hidden.priority = -1;
 
+#if 0	/* XXX */
+  gtk_list_store_append(store, &setting->show_good_title.all_rules_iter);
+  gtk_list_store_set(store, &setting->show_good_title.all_rules_iter,
+	FILTER_RULE, THREADLIST_FILTER_RULE_SHOW_GOOD_TITLE_THREAD,
+	FILTER_RULE_PRIORITY, -1,
+	-1);
+  setting->show_good_title.priority = -1;
+
+  gtk_list_store_append(store, &setting->hide_no_good_title.all_rules_iter);
+  gtk_list_store_set(store, &setting->hide_no_good_title.all_rules_iter,
+	FILTER_RULE, THREADLIST_FILTER_RULE_HIDE_NO_GOOD_TITLE_THREAD,
+	FILTER_RULE_PRIORITY, -1,
+	-1);
+  setting->hide_no_good_title.priority = -1;
+#endif
+
   store = gtk_list_store_new(FILTER_RULE_N_COLUMNS, G_TYPE_INT, G_TYPE_INT);
   setting->current_rules_model = GTK_TREE_MODEL(store);
 
@@ -1361,6 +1381,14 @@ get_threadlist_filter_rule_string(int rule)
     case THREADLIST_FILTER_RULE_HIDE_HIDDEN_THREAD:
       return hide_hidden;
 
+#if 0	/* XXX */
+    case THREADLIST_FILTER_RULE_SHOW_GOOD_TITLE_THREAD:
+      return show_good_title;
+
+    case THREADLIST_FILTER_RULE_HIDE_NO_GOOD_TITLE_THREAD:
+      return hide_no_good_title;
+#endif
+
     default:
       return invalid_rule;
     }
@@ -1426,6 +1454,14 @@ get_relation_for_rule(ThreadlistFilterSetting *setting, gint rule)
     case THREADLIST_FILTER_RULE_HIDE_HIDDEN_THREAD:
       return &setting->hide_hidden;
 
+#if 0	/* XXX */
+    case THREADLIST_FILTER_RULE_SHOW_GOOD_TITLE_THREAD:
+      return &setting->show_good_title;
+
+    case THREADLIST_FILTER_RULE_HIDE_NO_GOOD_TITLE_THREAD:
+      return &setting->hide_no_good_title;
+#endif
+
     default:
       break;
     }
@@ -1467,9 +1503,9 @@ text_set_cell_data_available_rule(GtkTreeViewColumn *column,
 #else	/* XXX: ġɤ꤬ɤʤʡ */
   g_value_init(&visible, G_TYPE_STRING);
   if (priority != -1)
-    g_value_set_static_string(&visible, "gray70");
+    g_value_set_static_string(&visible, "gray50");
   else
-    g_value_set_static_string(&visible, "black");
+    g_value_set_static_string(&visible, NULL);
   g_object_set_property((GObject *)renderer, "foreground", &visible);
 #endif
 }
@@ -1576,141 +1612,80 @@ threadlist_filter_check_thread(ThreadlistFilter *filter,
       switch (*cur_rule)
 	{
 	case THREADLIST_FILTER_RULE_SHOW_ALL:
-#if DEBUG_GUI_MOST
-	  fprintf(stderr, "TRUE: show all\n");
-#endif
 	  return TRUE;
 
 	case THREADLIST_FILTER_RULE_HIDE_ALL:
-#if DEBUG_GUI_MOST
-	  fprintf(stderr, "FALSE: hide all\n");
-#endif
 	  return FALSE;
 
 	case THREADLIST_FILTER_RULE_SHOW_FAVORITE:
 	  if (thread_info->view_flags & BBS_THREAD_FAVORITE)
-	    {
-#if DEBUG_GUI_MOST
-	      fprintf(stderr, "TRUE: show favorite\n");
-#endif
-	      return TRUE;
-	    }
+	    return TRUE;
 	  break;
       
 	case THREADLIST_FILTER_RULE_HIDE_NON_FAVORITE:
 	  if ((thread_info->view_flags & BBS_THREAD_FAVORITE) == 0)
-	    {
-#if DEBUG_GUI_MOST
-	      fprintf(stderr, "FALSE: hide non favorite\n");
-#endif
-	      return FALSE;
-	    }
+	    return FALSE;
 	  break;
       
 	case THREADLIST_FILTER_RULE_SHOW_THREAD_SEEN:
 	  if (thread->number_of_responses_read > 0)
-	    {
-#if DEBUG_GUI_MOST
-	      fprintf(stderr, "TRUE: show thread seen\n");
-#endif
-	      return TRUE;
-	    }
+	    return TRUE;
 	  break;
 
 	case THREADLIST_FILTER_RULE_HIDE_THREAD_NEVER_SEEN:
 	  if (thread->number_of_responses_read == 0)
-	    {
-#if DEBUG_GUI_MOST
-	      fprintf(stderr, "FALSE: hide thread never seen\n");
-#endif
-	      return FALSE;
-	    }
+	    return FALSE;
 	  break;
 
 	case THREADLIST_FILTER_RULE_SHOW_THREAD_SEEN_OFFLINE:
 	  if (application->config.offline
 	      && thread->number_of_responses_read > 0)
-	    {
-#if DEBUG_GUI_MOST
-	      fprintf(stderr, "TRUE: show thread seen (offline)\n");
-#endif
-	      return TRUE;
-	    }
+	    return TRUE;
 	  break;
 
 	case THREADLIST_FILTER_RULE_HIDE_THREAD_NEVER_SEEN_OFFLINE:
 	  if (application->config.offline
 	      && thread->number_of_responses_read == 0)
-	    {
-#if DEBUG_GUI_MOST
-	      fprintf(stderr, "FALSE: hide thread never seen (offline)\n");
-#endif
-	      return FALSE;
-	    }
+	    return FALSE;
 	  break;
 
 	case THREADLIST_FILTER_RULE_SHOW_NEW_COMER_THREAD:
 	  if (thread_info->view_rank == 0
 	      || (thread_info->view_flags & BBS_THREAD_NEW) != 0)
-	    {
-#if DEBUG_GUI_MOST
-	      fprintf(stderr, "TRUE: show new comer thread.\n");
-#endif
-	      return TRUE;
-	    }
+	    return TRUE;
 	  break;
 
 	case THREADLIST_FILTER_RULE_SHOW_THREAD_WITH_NEW_RESPONSES:
 	  if (thread->number_of_responses_on_server
 	      > thread->number_of_responses_read)
-	    {
-#if DEBUG_GUI_MOST
-	      fprintf(stderr, "TRUE: show thread with new responses.\n");
-#endif
-	      return TRUE;
-	    }
+	    return TRUE;
 	  break;
 
 	case THREADLIST_FILTER_RULE_HIDE_THREAD_WITHOUT_NEW_RESPONSES:
 	  if (thread->number_of_responses_on_server
 	      <= thread->number_of_responses_read)
-	    {
-#if DEBUG_GUI_MOST
-	      fprintf(stderr, "FALSE: hide thread without new responses.\n");
-#endif
-	      return FALSE;
-	    }
+	    return FALSE;
 	  break;
 
 	case THREADLIST_FILTER_RULE_SHOW_DAT_DROPPED_THREAD:
 	  if (thread->flags & OCHUSHA_BBS_THREAD_DAT_DROPPED)
-	    {
-#if DEBUG_GUI_MOST
-	      fprintf(stderr, "TRUE: show thread whose dat was dropped.\n");
-#endif
-	      return TRUE;
-	    }
+	    return TRUE;
 	  break;
 
 	case THREADLIST_FILTER_RULE_HIDE_MUCH_IGNORED_THREAD:
 	  if (threshold != 0
 	      && thread_info->view_ignored > threshold)
-	    {
-#if DEBUG_GUI_MOST
-	      fprintf(stderr, "FALSE: hide thread that is too many times ignored.\n");
-#endif
-	      return FALSE;
-	    }
+	    return FALSE;
 	  break;
 
 	case THREADLIST_FILTER_RULE_HIDE_HIDDEN_THREAD:
 	  if ((thread_info->view_flags & BBS_THREAD_HIDDEN) != 0)
-	    {
-#if DEBUG_GUI_MOST
-	      fprintf(stderr, "FALSE: hide thread marked as hidden.\n");
-#endif
-	      return FALSE;
-	    }
+	    return FALSE;
+	  break;
+
+	case THREADLIST_FILTER_RULE_SHOW_GOOD_TITLE_THREAD:
+	case THREADLIST_FILTER_RULE_HIDE_NO_GOOD_TITLE_THREAD:
+	  fprintf(stderr, "Not implemented yet.\n");
 	  break;
 
 #if DEBUG_GUI_MOST
