@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: threadlist_view.h,v 1.12 2003/11/26 10:04:16 fuyu Exp $
+ * $Id: threadlist_view.h,v 1.17 2003/12/05 08:40:54 fuyu Exp $
  */
 
 #ifndef _THREADLIST_VIEW_H_
@@ -52,19 +52,24 @@ typedef struct _ThreadlistViewClass ThreadlistViewClass;
 typedef struct _ThreadlistInfo ThreadlistInfo;
 
 
-typedef enum {
-  THREADLIST_SEARCH_DIRECTION_BACKWARD,
-  THREADLIST_SEARCH_DIRECTION_FORWARD
-} ThreadlistSearchDirection;
+typedef enum
+{
+  LIST_ENTRY_FOREGROUND_NORMAL = 0,
+  LIST_ENTRY_FOREGROUND_EMPH,
+  LIST_ENTRY_FOREGROUND_STRONG,
+  LIST_ENTRY_FOREGROUND_HIDDEN,
+  NUMBER_OF_LIST_ENTRY_FOREGROUND_COLORS
+} ThreadlistEntryForeground;
 
 
-typedef enum {
-  THREADLIST_SEARCH_ACTION_FORWARD,
-  THREADLIST_SEARCH_ACTION_BACKWARD,
-  THREADLIST_SEARCH_ACTION_REGEXP_FORWARD,
-  THREADLIST_SEARCH_ACTION_REGEXP_BACKWARD,
-  THREADLIST_SEARCH_ACTION_TERMINATE
-} ThreadlistSearchAction;
+typedef enum
+{
+  LIST_ENTRY_BACKGROUND_NORMAL = 0,
+  LIST_ENTRY_BACKGROUND_EMPH,
+  LIST_ENTRY_BACKGROUND_STRONG,
+  LIST_ENTRY_BACKGROUND_HIDDEN,
+  NUMBER_OF_LIST_ENTRY_BACKGROUND_COLORS,
+} ThreadlistEntryBackground;
 
 
 struct _ThreadlistView
@@ -84,6 +89,7 @@ struct _ThreadlistView
 
   GtkTreeSelection *selection;
 
+  gboolean default_open_in_tab;
 
   /* Ϣ */
   gboolean (*title_match_func)(const gchar *title, gpointer search_data);
@@ -101,6 +107,21 @@ struct _ThreadlistView
 };
 
 
+typedef enum {
+  THREADLIST_SEARCH_DIRECTION_BACKWARD,
+  THREADLIST_SEARCH_DIRECTION_FORWARD
+} ThreadlistSearchDirection;
+
+
+typedef enum {
+  THREADLIST_SEARCH_ACTION_FORWARD,
+  THREADLIST_SEARCH_ACTION_BACKWARD,
+  THREADLIST_SEARCH_ACTION_REGEXP_FORWARD,
+  THREADLIST_SEARCH_ACTION_REGEXP_BACKWARD,
+  THREADLIST_SEARCH_ACTION_TERMINATE
+} ThreadlistSearchAction;
+
+
 struct _ThreadlistViewClass
 {
   GtkTreeViewClass parent_class;
@@ -128,7 +149,10 @@ struct _ThreadlistViewClass
 			   OchushaBBSThread *thread);
   gboolean (*back_view)(ThreadlistView *threadlist_view,
 			OchushaBBSThread *thread);
+  void (*write_response)(ThreadlistView *threadlist_view,
+			 OchushaBBSThread *thread);
 
+  void (*close_threadlist)(ThreadlistView *threadlist_view);
   gboolean (*interactive_search)(ThreadlistView *threadlist_view,
 				 ThreadlistSearchAction search_action);
 
@@ -152,8 +176,8 @@ typedef struct _ThreadlistEntryVisualParameter
 {
   guint flags			: 2;	/* ThreadlistEntryVisualFlagsOR */
 
-  guint foreground_color	: 4;	/* 16¿뤯餤 */
-  guint background_color	: 4;	/* 16¿뤯餤 */
+  guint foreground_color	: 4;	/* ThreadlistEntryForeground */
+  guint background_color	: 4;	/* ThreadlistEntryBackground */
 
   guint reserved		: 22;
 } ThreadlistEntryVisualParameter;
@@ -164,38 +188,24 @@ typedef struct _ThreadlistEntryVisualParameter
 #define THREADLIST_ENTRY_VISUAL_BACKGROUND_COLOR_WIDTH	4
 
 
-/*
- * ʲϤäỌ̇̄Τ̾ˤ٤桼ǽˤ뤳Ȥ
- * ͤʤ顢ϤΥåȤGUIԤ¦Ƿ
- * ٤
- *
- * ġĤȸ櫓ǰŪȤȤˤƤ
- */
-typedef enum
-{
-  LIST_ENTRY_FOREGROUND_COLOR_NORMAL = 0,
-  LIST_ENTRY_FOREGROUND_COLOR_BLUE = 1,
-  LIST_ENTRY_FOREGROUND_COLOR_RED = 2,
-  LIST_ENTRY_FOREGROUND_COLOR_GREEN = 3,
-  LIST_ENTRY_FOREGROUND_COLOR_GRAY50 = 4,
-  LIST_ENTRY_FOREGROUND_COLOR_GRAY75 = 5,
-} ThreadlistEntryForegroundColor;
-
-
-typedef enum
-{
-  LIST_ENTRY_BACKGROUND_COLOR_NORMAL = 0,
-  LIST_ENTRY_BACKGROUND_COLOR_LAVENDER = 1,
-  LIST_ENTRY_BACKGROUND_COLOR_PINK = 2,
-  LIST_ENTRY_BACKGROUND_COLOR_DARK_SEA_GREEN1 = 3,
-  LIST_ENTRY_BACKGROUND_COLOR_GRAY75 = 4,
-  LIST_ENTRY_BACKGROUND_COLOR_GRAY90 = 5,
-} ThreadlistEntryBackgroundColor;
-
-
 GType threadlist_view_get_type(void);
 GtkWidget *threadlist_view_new(void);
 
+const char *threadlist_view_get_foreground(ThreadlistView *view,
+					   ThreadlistEntryForeground code);
+void threadlist_view_set_foreground(ThreadlistView *view,
+				    ThreadlistEntryForeground code,
+				    const char *color);
+const char *threadlist_view_get_background(ThreadlistView *view,
+					   ThreadlistEntryBackground code);
+void threadlist_view_set_background(ThreadlistView *view,
+				    ThreadlistEntryBackground code,
+				    const char *color);
+
+gboolean threadlist_view_get_default_open_in_tab(ThreadlistView *view);
+void threadlist_view_set_default_open_in_tab(ThreadlistView *view,
+					     gboolean default_open_in_tab);
+
 void threadlist_view_append_rank(ThreadlistView *view);
 void threadlist_view_append_mark(ThreadlistView *view);
 void threadlist_view_append_title(ThreadlistView *view);
@@ -241,6 +251,13 @@ gboolean threadlist_view_find_next(ThreadlistView *view,
 				   gboolean enable_wrap,
 				   gboolean include_current_pos,
 				   gpointer search_data);
+
+void threadlist_entry_set_foreground(ThreadlistEntryForeground color,
+				     const char *color_name);
+
+void threadlist_entry_set_background(ThreadlistEntryBackground color,
+				     const char *color_name);
+
 #ifdef __cplusplus
 } // extern "C"
 #endif
