@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: gziputils.c,v 1.4 2003/06/10 21:14:58 fuyu Exp $
+ * $Id: gziputils.c,v 1.5 2003/12/15 17:15:11 fuyu Exp $
  */
 
 #include "config.h"
@@ -33,6 +33,8 @@
 
 #include "gziputils.h"
 
+#include <glib.h>
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -43,10 +45,7 @@
 #define DEBUG_GZIP	0
 #define DEBUG_GZIP_MOST	0
 
-static int check_gzip_header(const char *buffer, int buffer_length);
-#if 0
-static gboolean check_gzip_header_old(z_stream *zstream);
-#endif
+static int check_gzip_header(const unsigned char *buffer, int buffer_length);
 
 
 struct _GzipBuffer
@@ -118,6 +117,14 @@ gzip_buffer_append_data(GzipBuffer *buffer, const char *data,
   fprintf(stderr, "gzip_buffer_append_data() called.\n");
 #endif
 
+#if 0	/* κrawǡФƤߤ¸ */
+  {
+    unsigned int i;
+    for (i = 0; i < length; i++)
+      printf("%c", data[i]);
+  }
+#endif
+
   if (buffer->status == GZIP_BUFFER_ERROR
       || buffer->status == GZIP_BUFFER_INFLATION_DONE)
     {
@@ -147,6 +154,7 @@ gzip_buffer_append_data(GzipBuffer *buffer, const char *data,
 #if DEBUG_GZIP
       fprintf(stderr, "check_gzip_header() returns %d\n", gzip_header_len);
 #endif
+
       if (gzip_header_len < 0)
 	{
 	  buffer->status = GZIP_BUFFER_ERROR;
@@ -202,6 +210,20 @@ gzip_buffer_append_data(GzipBuffer *buffer, const char *data,
       switch (result)
 	{
 	case Z_STREAM_END:
+#if 0
+	  {
+	    int avail_in = zstream->avail_in;
+	    unsigned char *garbage = zstream->next_in;
+	    if (avail_in > 0)
+	      {
+		fprintf(stderr, "zstream->avail_in=%d\n", zstream->avail_in);
+		fprintf(stderr, "BEGIN OF GARBAGES\n");
+		while (avail_in-- > 0)
+		  fprintf(stderr, "0x%02x ", *garbage++);
+		fprintf(stderr, "\nEND OF GARBAGES\n");
+	      }
+	  }
+#endif
 	  buffer->status = GZIP_BUFFER_INFLATION_DONE;
 	  return buffer->status;
 
@@ -238,102 +260,6 @@ gzip_buffer_append_data(GzipBuffer *buffer, const char *data,
 }
 
 
-#if 0	/* ⤦ȤäƤʤ */
-/*
- * inputinput_lengthʬޤޤgzipǡǤȸʤ
- * outputΰinflate롣
- */
-gboolean
-inflate_gzip_buffer(const char *input, unsigned int input_length,
-		    char **output, unsigned int *output_length)
-{
-  z_stream zstream;
-  char *out_buf = *output;
-  unsigned int out_len = *output_length;
-
-  int gzip_header_len = check_gzip_header(input, input_length);
-  if (gzip_header_len < 0)
-    {
-#if DEBUG_GZIP
-      fprintf(stderr, "inflation failed: invalid gzip header.\n");
-#endif
-      return FALSE;
-    }
-
-  zstream.next_in = (Bytef *)(input + gzip_header_len);
-  zstream.avail_in = input_length - gzip_header_len;
-  zstream.next_out = Z_NULL;
-  zstream.avail_out = 0;
-  zstream.zalloc = Z_NULL;
-  zstream.zfree = Z_NULL;
-  zstream.opaque = Z_NULL;
-
-  if (inflateInit2(&zstream, -MAX_WBITS) != Z_OK)
-    {
-#if DEBUG_GZIP
-      fprintf(stderr, "inflation failed: inflateInit2 failed.\n");
-#endif
-      return FALSE;
-    }
-
-  if (out_buf == NULL || out_len < input_length * 2)
-    {
-      out_len = input_length * 2;	/* 褺Ϥܽ */
-      out_buf = (char *)G_REALLOC(out_buf, out_len);
-    }
-
-  zstream.next_out = out_buf;
-  zstream.avail_out = out_len;
-
-  while (TRUE)
-    {
-      switch (inflate(&zstream, Z_NO_FLUSH))
-	{
-	case Z_STREAM_END:
-	  {
-	    inflateEnd(&zstream);
-	    *output = (char *)G_REALLOC(out_buf, zstream.total_out);
-	    *output_length = zstream.total_out;
-	    return TRUE;
-	  }
-
-	case Z_DATA_ERROR:
-	  fprintf(stderr, "inflation failed: not gzip data.\n");
-	  goto inflation_failed;
-
-	case Z_OK:
-	  /* output buffer full */
-	  {
-	    out_len *= 2;	/*  */
-	    out_buf = (char *)G_REALLOC(out_buf, out_len);
-	    zstream.next_out = out_buf + zstream.total_out;
-	    zstream.avail_out += out_len / 2;
-	    break;
-	  }
-	default:
-#if DEBUG_GZIP
-	  fprintf(stderr, "inflation failed: %s\n",
-		  (zstream.msg != NULL) ? zstream.msg : "unknown error");
-#endif
-	  goto inflation_failed;
-	}
-    }
-
- inflation_failed:
-  inflateEnd(&zstream);
-
-  if (*output == NULL)
-    G_FREE(out_buf);	/* ߤout_bufϤδؿǿ˳ݤ */
-  else
-    *output = out_buf;	/* reallocΤʤcallerˤޤ */
-
-  *output_length = 0;
-
-  return FALSE;
-}
-#endif
-
-
 #define HEAD_CRC     0x02 /* bit 1 set: header CRC present */
 #define EXTRA_FIELD  0x04 /* bit 2 set: extra field present */
 #define ORIG_NAME    0x08 /* bit 3 set: original file name present */
@@ -342,14 +268,14 @@ inflate_gzip_buffer(const char *input, unsigned int input_length,
 
 
 static int
-check_gzip_header(const char *buffer, int buffer_length)
+check_gzip_header(const unsigned char *buffer, int buffer_length)
 {
   unsigned int method;	/* method byte */
   unsigned int flags;	/* flags byte */
   unsigned int len;
-  static const char gz_magic[2] = { 0x1f, 0x8b };
-  const char *cur_pos = buffer;
-  const char *tail_pos = buffer + buffer_length;
+  static const char gz_magic[] = { 0x1f, 0x8b, '\0' };
+  const unsigned char *cur_pos = buffer;
+  const unsigned char *tail_pos = buffer + buffer_length;
 
   if (cur_pos + 4 >= tail_pos)
     {
@@ -359,17 +285,29 @@ check_gzip_header(const char *buffer, int buffer_length)
       return 0;
     }
 
-  /* Check the gzip magic header */
-  for (len = 0; len < 2; len++)
+  /* Find the gzip magic header */
+  cur_pos = g_strstr_len(buffer, buffer_length, gz_magic);
+  if (cur_pos == NULL)
     {
-      if (*cur_pos++ != gz_magic[len])
-	{
 #if DEBUG_GZIP
-	  fprintf(stderr, "No matching magic number.\n");
+      int i;
+      fprintf(stderr,
+	      "Too short for gzip header or no matching magic number.\n");
+      for (i = 0; i < buffer_length; i++)
+	fprintf(stderr, "0x%02x ", buffer[i]);
 #endif
-	  return -1;
-	}
+      return 0;
     }
+#if DEBUG_GZIP
+  if (cur_pos != buffer)
+    {
+      int i;
+      fprintf(stderr, "leading %d bytes skipped.\n", cur_pos - buffer);
+      for (i = 0; i < cur_pos - buffer + 2; i++)
+	fprintf(stderr, "0x%02x ", buffer[i]);
+    }
+#endif
+  cur_pos += 2;	/* skip magic */
 
   method = *cur_pos++;
   flags = *cur_pos++;
@@ -410,8 +348,10 @@ check_gzip_header(const char *buffer, int buffer_length)
 
       if (cur_pos >= tail_pos)
 	{
+#if DEBUG_GZIP
 	  fprintf(stderr, "Too short for gzip header.\n");
-	  return FALSE;
+#endif
+	  return 0;
 	}
     }
 
@@ -424,8 +364,10 @@ check_gzip_header(const char *buffer, int buffer_length)
       while (*cur_pos++ != '\0')
 	if (cur_pos >= tail_pos)
 	  {
+#if DEBUG_GZIP
 	    fprintf(stderr, "Too short for gzip header.\n");
-	    return FALSE;
+#endif
+	    return 0;
 	  }
     }
 
@@ -438,8 +380,10 @@ check_gzip_header(const char *buffer, int buffer_length)
       while (*cur_pos++ != '\0')
 	if (cur_pos >= tail_pos)
 	  {
+#if DEBUG_GZIP
 	    fprintf(stderr, "Too short for gzip header.\n");
-	    return FALSE;
+#endif
+	    return 0;
 	  }
     }
 
@@ -452,129 +396,12 @@ check_gzip_header(const char *buffer, int buffer_length)
       cur_pos += 2;
       if (cur_pos >= tail_pos)
 	{
+#if DEBUG_GZIP
 	  fprintf(stderr, "Too short for gzip header.\n");
-	  return FALSE;
+#endif
+	  return 0;
 	}
     }
 
   return cur_pos - buffer;
 }
-
-
-#if 0
-static gboolean
-check_gzip_header_old(z_stream *zstream)
-{
-  unsigned int method;	/* method byte */
-  unsigned int flags;	/* flags byte */
-  unsigned int len;
-  static const char gz_magic[2] = { 0x1f, 0x8b };
-  char *cur_pos = zstream->next_in;
-  char *tail_pos = zstream->next_in + zstream->avail_in;
-
-  if (cur_pos + 4 >= tail_pos)
-    {
-      fprintf(stderr, "Too short for gzip header.\n");
-      return FALSE;
-    }
-
-  /* Check the gzip magic header */
-  for (len = 0; len < 2; len++)
-    {
-      if (*cur_pos++ != gz_magic[len])
-	{
-	  fprintf(stderr, "No matching magic number.\n");
-	  return FALSE;
-	}
-    }
-
-  method = *cur_pos++;
-  flags = *cur_pos++;
-
-#if DEBUG_GZIP_MOST
-  fprintf(stderr, "flags: 0x%x\n", flags);
-#endif
-
-  if (method != Z_DEFLATED || (flags & RESERVED) != 0)
-    return FALSE;	/* Invalid header */
-
-  /* Discard time, xflags and OS code: */
-  cur_pos += 6;
-  if (cur_pos >= tail_pos)
-    {
-      fprintf(stderr, "Too short for gzip header.\n");
-      return FALSE;
-    }
-
-  if ((flags & EXTRA_FIELD) != 0)
-    {
-      if (cur_pos + 2 >= tail_pos)
-	{
-	  fprintf(stderr, "Too short for gzip header.\n");
-	  return FALSE;
-	}
-#if DEBUG_GZIP_MOST
-      fprintf(stderr, "skipping the extra field\n", cur_pos);
-#endif
-      /* skip the extra field */
-      len = (unsigned int)*cur_pos++;
-      len += ((unsigned int)*cur_pos++) << 8;
-      cur_pos += len;
-
-      if (cur_pos >= tail_pos)
-	{
-	  fprintf(stderr, "Too short for gzip header.\n");
-	  return FALSE;
-	}
-    }
-
-  if ((flags & ORIG_NAME) != 0)
-    {
-#if DEBUG_GZIP_MOST
-      fprintf(stderr, "ORIG_NAME = \"%s\"\n", cur_pos);
-#endif
-      /* skip the original file name */
-      while (*cur_pos++ != '\0')
-	if (cur_pos >= tail_pos)
-	  {
-	    fprintf(stderr, "Too short for gzip header.\n");
-	    return FALSE;
-	  }
-    }
-
-  if ((flags & COMMENT) != 0)
-    {
-#if DEBUG_GZIP_MOST
-      fprintf(stderr, "COMMENT = \"%s\"\n", cur_pos);
-#endif
-      /* skip the .gz file comment */
-      while (*cur_pos++ != '\0')
-	if (cur_pos >= tail_pos)
-	  {
-	    fprintf(stderr, "Too short for gzip header.\n");
-	    return FALSE;
-	  }
-    }
-
-  if ((flags & HEAD_CRC) != 0)
-    {
-#if DEBUG_GZIP_MOST
-      fprintf(stderr, "skipping CRC\n");
-#endif
-      /* skip the header crc */
-      cur_pos += 2;
-      if (cur_pos >= tail_pos)
-	{
-	  fprintf(stderr, "Too short for gzip header.\n");
-	  return FALSE;
-	}
-    }
-
-  len = cur_pos - ((char *)zstream->next_in);
-  zstream->avail_in -= len;
-  zstream->next_in = cur_pos;
-  zstream->total_in += len;
-
-  return TRUE;
-}
-#endif
