@@ -36,7 +36,10 @@ extern void libochusha_marshal_BOOLEAN__OBJECT_INT_STRING (GClosure     *closure
 /* VOID:STRING (marshal.list:5) */
 #define libochusha_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING
 
-/* VOID:OBJECT,POINTER (marshal.list:6) */
+/* VOID:VOID (marshal.list:6) */
+#define libochusha_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID
+
+/* VOID:OBJECT,POINTER (marshal.list:7) */
 extern void libochusha_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                                      GValue       *return_value,
                                                      guint         n_param_values,
