@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_table.c,v 1.14 2003/11/21 21:30:03 fuyu Exp $
+ * $Id: ochusha_bbs_table.c,v 1.16 2003/12/01 07:26:37 fuyu Exp $
  */
 
 #include "config.h"
@@ -32,6 +32,7 @@
 #include "ochusha.h"
 #include "ochusha_bbs_table.h"
 #include "ochusha_board_2ch.h"
+#include "ochusha_board_jbbs.h"
 #include "ochusha_board_category.h"
 #include "ochusha_bulletin_board.h"
 #include "ochusha_utils_2ch.h"
@@ -714,17 +715,7 @@ endElementHandler(void *context, const xmlChar *name)
 	      fprintf(stderr, "Wrong implementation found.\n");
 	      abort();
 	    }
-	  /* NOTE:
-	   * stringattributeƤSAXѡԹ()ǡĤ
-	   * ޤǤheapˤʤΤǤstrdup
-	   * SAXѡԹȤΤϡΥץŪˤ1ʸǤ٤
-	   * ƤSAXѡŪʣǤȤƸƤޤ礬ꡢ
-	   * Ϣ뤹뤿ΰХåեɬפǤ뤫顣
-	   */
-	  if (sax_context->current_attr_val != NULL)
-	    sax_context->current_attr_val
-	      = G_STRDUP(sax_context->current_attr_val);
-	  else
+	  if (sax_context->current_attr_val == NULL)
 	    sax_context->current_attr_val = G_STRDUP("");
 	  return;
 	}
@@ -831,13 +822,14 @@ endElementHandler(void *context, const xmlChar *name)
 		{
 		case OCHUSHA_BBS_TYPE_2CH:
 		case OCHUSHA_BBS_TYPE_2CHLIKE_EUCJP:
+		  board = ochusha_board_2ch_new(board_name, base_url);
+		  break;
+
 		case OCHUSHA_BBS_TYPE_JBBS:
 		case OCHUSHA_BBS_TYPE_MACHIBBS:
 		case OCHUSHA_BBS_TYPE_JBBS_SHITARABA:
 		case OCHUSHA_BBS_TYPE_MITINOKU:
-		  board = ochusha_board_2ch_new(board_name, base_url);
-		  break;
-
+		  board = ochusha_board_jbbs_new(board_name, base_url);
 		default:
 		  /* board = NULL;  XXX ȤꤢĤ̵ */
 		  break;
@@ -904,7 +896,6 @@ endElementHandler(void *context, const xmlChar *name)
 }
 
 
-#define STRING_BUFFER_LENGTH	1024
 static void
 charactersHandler(void *context, const xmlChar *ch, int len)
 {
@@ -913,17 +904,15 @@ charactersHandler(void *context, const xmlChar *ch, int len)
   if (sax_context->state == SAX_CATEGORY_ATTRIBUTE_STRING
       || sax_context->state == SAX_CATEGORY_BOARD_ATTRIBUTE_STRING)
     {
-      static char buffer[STRING_BUFFER_LENGTH] = "";
-      int value_len;
       if (sax_context->current_attr_val == NULL)
-	buffer[0] = '\0';
-
-      value_len = strlen(buffer);
-      if (value_len + len >= STRING_BUFFER_LENGTH)
-	len = STRING_BUFFER_LENGTH - value_len - 1;
-
-      strncat(buffer, ch, len);
-      sax_context->current_attr_val = buffer;
+	sax_context->current_attr_val = G_STRNDUP(ch, len);
+      else
+	{
+	  int old_len = strlen(sax_context->current_attr_val);
+	  sax_context->current_attr_val
+	    = G_REALLOC(sax_context->current_attr_val, old_len + len + 1);
+	  strncat(sax_context->current_attr_val + old_len, ch, len);
+	}
     }
 }
 
