@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_thread.c,v 1.16 2003/12/08 02:29:45 fuyu Exp $
+ * $Id: ochusha_bbs_thread.c,v 1.17 2003/12/15 17:22:29 fuyu Exp $
  */
 
 #include "config.h"
@@ -200,7 +200,7 @@ ochusha_bbs_thread_finalize(GObject *object)
 
   if (thread->board != NULL)
     {
-#if 0	/* QƂ[v̂ŉ^pŃJo[ */
+#if 0	/* Ȥ롼פΤǱѤǥС */
       g_object_unref(thread->board);
 #endif
       thread->board = NULL;
@@ -299,7 +299,7 @@ ochusha_bbs_thread_set_board(OchushaBBSThread *thread,
   if (thread->board == board)
     return;
 
-#if 0	/* QƂ[vĂ܂̂ŉ^pŃJo[ */
+#if 0	/* Ȥ롼פƤޤΤǱѤǥС */
   if (thread->board != NULL)
     g_object_unref(G_OBJECT(thread->board));
 
@@ -580,6 +580,7 @@ ochusha_bbs_thread_remove_cache(OchushaBBSThread *thread,
   g_return_if_fail(klass->remove_cache != NULL);
 
   thread->number_of_responses_read = 0;
+  thread->flags &= ~OCHUSHA_BBS_THREAD_STOPPED;
 
   return (*klass->remove_cache)(thread, config);
 }
@@ -592,6 +593,8 @@ ochusha_bbs_thread_read_threadlist_element(OchushaBBSThread *thread,
   thread->number_of_responses_read
     = ochusha_utils_get_attribute_int(thread_attributes,
 				      "number_of_responses_read");
+  if (thread->number_of_responses_read == 0)
+    thread->flags &= ~OCHUSHA_BBS_THREAD_STOPPED;
   thread->flags = ochusha_utils_get_attribute_int(thread_attributes,
 						  "flags");
 }
