@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_2ch.c,v 1.23 2003/12/14 16:10:28 fuyu Exp $
+ * $Id: ochusha_board_2ch.c,v 1.24 2003/12/16 17:25:59 fuyu Exp $
  */
 
 #include "config.h"
@@ -40,13 +40,24 @@
 #include <glib-object.h>
 #include <glib.h>
 
+#include <fcntl.h>
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+
+#include <sys/types.h>
+#include <sys/mman.h>
+
 #include <time.h>
 #include <unistd.h>
 
 
+#ifndef MAP_NOCORE
+# define MAP_NOCORE	0
+#endif
+
+
 static OchushaBulletinBoardClass *parent_class = NULL;
 
 
@@ -64,6 +75,8 @@ static void ochusha_board_2ch_write_boardlist_element(
 static const char *ochusha_board_2ch_get_subject_txt_encoding(
 						OchushaBulletinBoard *board);
 
+static void ochusha_board_2ch_recover_threadlist(OchushaBulletinBoard *board,
+						 OchushaConfig *config);
 static char *ochusha_board_2ch_generate_base_path(OchushaBulletinBoard *board,
 						  const char *url);
 static char *ochusha_board_2ch_generate_board_id(OchushaBulletinBoard *board,
@@ -139,6 +152,7 @@ ochusha_board_2ch_class_init(OchushaBoard2chClass *klass)
   b_class->read_boardlist_element = ochusha_board_2ch_read_boardlist_element;
   b_class->write_boardlist_element = ochusha_board_2ch_write_boardlist_element;
 
+  b_class->recover_threadlist = ochusha_board_2ch_recover_threadlist;
   b_class->generate_base_path = ochusha_board_2ch_generate_base_path;
   b_class->generate_board_id = ochusha_board_2ch_generate_board_id;
   b_class->thread_new = ochusha_board_2ch_thread_new;
@@ -266,6 +280,130 @@ ochusha_board_2ch_get_subject_txt_encoding(OchushaBulletinBoard *board)
 }
 
 
+static void
+munmap_when_finished(OchushaAsyncBuffer *buffer)
+{
+  munmap((void *)buffer->buffer, buffer->length);
+}
+
+
+static gboolean
+recover_title(OchushaBBSThread *thread, const char *title, gpointer unused)
+{
+  const char *encoding
+    = ochusha_bbs_thread_get_response_character_encoding(thread);
+  iconv_helper *helper
+    = ochusha_bbs_thread_get_response_iconv_helper(thread);
+  iconv_t converter = iconv_open(helper ? "UTF-8" : "UTF-8//IGNORE", encoding);
+  gchar *recovered_title;
+
+  if (converter == (iconv_t)-1)
+    return FALSE;
+
+  recovered_title = simple_string_canon(title, -1, converter, helper);
+  ochusha_bbs_thread_set_title(thread, recovered_title);
+
+  G_FREE(recovered_title);
+  iconv_close(converter);
+
+  return FALSE;
+}
+
+
+static void
+ochusha_board_2ch_recover_threadlist(OchushaBulletinBoard *board,
+				     OchushaConfig *config)
+{
+  GDir *dir;
+  char *dat_dirname;
+  const char *dat_filename;
+  char path[PATH_MAX];
+
+  g_return_if_fail(OCHUSHA_IS_BOARD_2CH(board));
+
+  if (snprintf(path, PATH_MAX, "cache/%s%s%s/dat",
+	       ochusha_bulletin_board_get_server(board),
+	       ochusha_bulletin_board_get_base_path(board),
+	       ochusha_bulletin_board_get_id(board)) >= PATH_MAX)
+    return;
+
+  dat_dirname = ochusha_config_find_directory(config, path);
+
+  if (dat_dirname == NULL)
+    return;
+
+  dir = g_dir_open(dat_dirname, 0, NULL);
+  G_FREE(dat_dirname);
+
+  g_return_if_fail(dir != NULL);
+
+  while (TRUE)
+    {
+      char *id;
+      const char *dat_pos;
+      OchushaBBSThread *thread;
+
+      dat_filename = g_dir_read_name(dir);
+      if (dat_filename == NULL)
+	break;
+
+      dat_pos = strstr(dat_filename, ".dat");
+      if (dat_pos == NULL || dat_pos[4] != '\0')
+	continue;
+
+      id = G_STRNDUP(dat_filename, dat_pos - dat_filename);
+
+      thread = ochusha_bulletin_board_lookup_bbs_thread_by_id(board, id);
+
+      if (thread == NULL)
+	{
+	  if (snprintf(path, PATH_MAX, "cache/%s%s%s/dat/%s",
+		       ochusha_bulletin_board_get_server(board),
+		       ochusha_bulletin_board_get_base_path(board),
+		       ochusha_bulletin_board_get_id(board),
+		       dat_filename) < PATH_MAX)
+	    {
+	      int fd = ochusha_config_open_file(config, path, O_RDONLY);
+	      if (fd >= 0)
+		{
+		  off_t len;
+		  char *buf;
+
+		  len = lseek(fd, 0, SEEK_END);
+		  buf = mmap(NULL, len, PROT_READ, MAP_NOCORE | MAP_PRIVATE,
+			     fd, 0);
+		  close(fd);
+		  if (buf != MAP_FAILED)
+		    {
+		      OchushaAsyncBuffer *dat_buffer
+			= ochusha_async_buffer_new(buf, len,
+						   munmap_when_finished);
+		      thread = ochusha_bulletin_board_bbs_thread_new(board, id,
+								     NULL);
+		      ochusha_bbs_thread_parse_responses(thread,
+							 dat_buffer,
+							 0, 1, TRUE,
+							 recover_title,
+							 NULL, NULL, NULL,
+							 NULL);
+		      g_object_unref(dat_buffer);
+		      thread->number_of_responses_read = 1;
+		      board->thread_list = g_slist_append(board->thread_list,
+							  thread);
+		    }
+		}
+	    }
+	}
+      else if (thread->number_of_responses_read == 0)
+	thread->number_of_responses_read = 1;
+
+      G_FREE(id);
+    };
+
+  g_dir_close(dir);
+}
+
+
 static char *
 ochusha_board_2ch_generate_base_path(OchushaBulletinBoard *board,
 				     const char *url)
