@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_category.c,v 1.5 2003/06/20 18:10:06 fuyu Exp $
+ * $Id: ochusha_board_category.c,v 1.6 2003/11/26 04:13:51 fuyu Exp $
  */
 
 #include "config.h"
@@ -360,10 +360,17 @@ ochusha_board_category_lookup_board_by_name(OchushaBoardCategory *category,
 	  (category)->attribute ? "true" : "false")
 
 #define OUTPUT_CATEGORY_ATTRIBUTE_STRING(file, category, attribute)	\
-  fprintf(file,								\
-	  "      <attribute name=\"" #attribute	"\">\n"			\
-	  "        <string>%s</string>\n"				\
-	  "      </attribute>\n", (category)->attribute)
+  do {									\
+    if ((category)->attribute)						\
+      {									\
+	gchar *text = g_markup_escape_text((category)->attribute, -1);	\
+	fprintf(file,							\
+		"      <attribute name=\"" #attribute	"\">\n"		\
+		"        <string>%s</string>\n"				\
+		"      </attribute>\n", text);				\
+	g_free(text);							\
+      }									\
+  } while (0)
 
 static void
 ochusha_board_category_read_boardlist_element(OchushaBoardCategory *category,
