@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_jbbs.c,v 1.4 2003/12/12 21:42:40 fuyu Exp $
+ * $Id: ochusha_board_jbbs.c,v 1.5 2003/12/14 16:10:28 fuyu Exp $
  */
 
 #include "config.h"
@@ -474,6 +474,12 @@ ochusha_board_jbbs_create_new_thread(OchushaBulletinBoard *board,
   else
     {
 #if DEBUG_POST
+      char *message[4096];
+      snprintf(message, 4096, "board_2ch(%s)->date == NULL%s\n",
+	       board->name);
+      ochusha_network_broker_output_log(broker, message);
+#endif
+#if DEBUG_POST_MOST
       fprintf(stderr, "board_2ch->date == NULL!\n");
 #endif
       time = ochusha_utils_get_utc_time(board_2ch->last_modified);
@@ -534,7 +540,7 @@ ochusha_board_jbbs_create_new_thread(OchushaBulletinBoard *board,
   return TRUE;
 
  error_exit:
-#if DEBUG_POST
+#if DEBUG_POST_MOST
   fprintf(stderr, "Error happen\n");
 #endif
 
