@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bulletin_board.c,v 1.18 2003/12/01 07:26:37 fuyu Exp $
+ * $Id: ochusha_bulletin_board.c,v 1.19 2003/12/16 17:25:59 fuyu Exp $
  */
 
 #include "config.h"
@@ -193,6 +193,7 @@ ochusha_bulletin_board_class_init(OchushaBulletinBoardClass *klass)
   klass->threadlist_read_thread_element = NULL;
   klass->threadlist_write_thread_element = NULL;
 
+  klass->recover_threadlist = NULL;
   klass->generate_base_path = NULL;
   klass->generate_board_id = ochusha_bulletin_board_generate_board_id;
   klass->thread_new = NULL;
@@ -1083,7 +1084,8 @@ getEntityHandler(void *context, const xmlChar *name)
 
 gboolean
 ochusha_bulletin_board_read_threadlist_xml(OchushaBulletinBoard *board,
-					   OchushaConfig *config)
+					   OchushaConfig *config,
+					   gboolean recover_mode)
 {
   SAXContext context =
     {
@@ -1138,6 +1140,14 @@ ochusha_bulletin_board_read_threadlist_xml(OchushaBulletinBoard *board,
 
   cleanup_sax_context(&context);
 
+  if (recover_mode)
+    {
+      OchushaBulletinBoardClass *board_class
+	= OCHUSHA_BULLETIN_BOARD_GET_CLASS(board);
+      if (board_class->recover_threadlist)
+	(*board_class->recover_threadlist)(board, config);
+    }
+
   if (context.state == SAX_ACCEPTED)
     {
       G_FREE(threadlist_xml);
