@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bulletin_board.h,v 1.10 2003/11/25 18:20:44 fuyu Exp $
+ * $Id: ochusha_bulletin_board.h,v 1.11 2003/12/16 17:25:59 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_BULLETIN_BOARD_H_
@@ -112,6 +112,8 @@ struct _OchushaBulletinBoardClass
 					  FILE *threadlist_xml);
 
   /* virtual function table */
+  void (*recover_threadlist)(OchushaBulletinBoard *board,
+			     OchushaConfig *config);
   char *(*generate_base_path)(OchushaBulletinBoard *board, const char *url);
   char *(*generate_board_id)(OchushaBulletinBoard *board, const char *url);
   OchushaBBSThread *(*thread_new)(OchushaBulletinBoard *board,
@@ -205,7 +207,8 @@ gboolean ochusha_bulletin_board_create_new_thread(OchushaBulletinBoard *board,
 
 gboolean ochusha_bulletin_board_read_threadlist_xml(
 					OchushaBulletinBoard *board,
-					OchushaConfig *config);
+					OchushaConfig *config,
+					gboolean recover_mode);
 gboolean ochusha_bulletin_board_write_threadlist_xml(
 					OchushaBulletinBoard *board,
 					OchushaConfig *config);
