@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_config.c,v 1.14 2003/12/01 07:26:37 fuyu Exp $
+ * $Id: ochusha_config.c,v 1.15 2003/12/16 17:25:59 fuyu Exp $
  */
 
 #include "config.h"
@@ -122,7 +122,37 @@ ochusha_config_find_file(const OchushaConfig *config, const char *filename)
 
 
 /*
- * ochusha_find_file
+ * ochusha_config_find_directory:
+ *
+ * ochushahomeǥ쥯ȥФpath̾filenameĥǥ쥯ȥ꤬
+ * ¸ߤ뤫ɤ򸡺¸ߤˤϥѥ̾ɽʸ֤
+ * callerϥѥ̾ʸפˤʤäfree()̳餦
+ */
+char *
+ochusha_config_find_directory(const OchushaConfig *config,
+			      const char *filename)
+{
+  int stat_result;
+  struct stat sb;
+  char pathname[PATH_MAX];
+
+  if (config->home == NULL)
+    return NULL;
+
+  if (snprintf(pathname, PATH_MAX, "%s/%s", config->home, filename)
+      >= PATH_MAX)
+    return NULL;
+
+  stat_result = stat(pathname, &sb);
+  if (stat_result == 0 && S_ISDIR(sb.st_mode) && access(pathname, R_OK) == 0)
+    return G_STRDUP(pathname);
+
+  return NULL;
+}
+
+
+/*
+ * ochusha_config_open_file
  *
  * ochushahomeǥ쥯ȥФpath̾filenameĥե
  * flagsͿ줿⡼ɤǳ
