@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_network_broker.c,v 1.35 2003/12/15 17:19:22 fuyu Exp $
+ * $Id: ochusha_network_broker.c,v 1.37 2003/12/16 19:46:44 fuyu Exp $
  */
 
 #include "config.h"
@@ -61,7 +61,7 @@
 
 
 #define DISABLE_PERSISTENT_CONNECTION		0
-#define ENABLE_GZIPPED_TRANSFER			0
+#define ENABLE_GZIPPED_TRANSFER			1
 #define ENABLE_GZIPPED_DIFFERENCIAL_READ	0
 
 #define CACHE_COMPARE_SIZE	128	/* Ĥѹǽˤ٤ */
@@ -173,12 +173,6 @@ ochusha_network_broker_class_init(OchushaNetworkBrokerClass *klass)
 		 libochusha_marshal_BOOLEAN__OBJECT,
 		 G_TYPE_BOOLEAN, 1,
 		 OCHUSHA_TYPE_ASYNC_BUFFER);
-  /*
-   * XXX: failˤOchushaAsyncBufferʤȤ⤢롣
-   *      OBJECTΥʥΰNULLݥ󥿤ϤȡGLibٹ
-   *      Ф⤷ʤΤǡٹ𤬽Ф褦ʤ顢OBJECTǤʤ
-   *      POINTERѹ٤
-   */
   broker_signals[ACCESS_FAILED_SIGNAL] =
     g_signal_new("access_failed",
 		 G_TYPE_FROM_CLASS(klass),
@@ -900,17 +894,19 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 
       if (state == ghttp_not_done)
 	{
-#if 1
-	  if (prev_proc == ghttp_proc_response_hdrs)
-	    read_ok = FALSE;
-#else
 	  const char *tmp_header;
 	  if (prev_proc == ghttp_proc_response_hdrs
 	      && (tmp_header = ghttp_get_header(request,
 						http_hdr_Transfer_Encoding))
 	      && strcasecmp(tmp_header, "chunked") == 0)
-	    read_ok = FALSE;
-#endif
+	    {
+	      /* ɤlibghttpasync⡼ɤǤ
+	       * Transfer-Encoding: chunkedפϡޤȤ˼갷ʤ͡
+	       */
+	      ghttp_set_sync(request, ghttp_sync);
+	      read_ok = FALSE;
+	    }
+
 	  if (read_ok)
 	    ghttp_flush_response_buffer(request);
 	}
@@ -1404,6 +1400,7 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
       int offset = len - CACHE_COMPARE_SIZE;
       GzipBuffer *gzip_buffer = NULL;
       const char *tmp_header;
+      ghttp_current_status current_status;
 
       if (offset < 0)
 	{
@@ -1508,14 +1505,18 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 	  goto finish_try_update_cache;
 	}
 
+      current_status = ghttp_get_status(request);
+
       while (TRUE)
 	{
 	  int body_len;
 	  char *body;
 	  gboolean before_cache_check = TRUE;
-	  ghttp_current_status current_status;
+	  ghttp_proc prev_proc;
 	  gboolean read_ok;
 
+	  prev_proc = current_status.proc;
+
 	  LOCK_WORKER_SYNC_OBJECT(sync_object);
 	  if (sync_object->interrupted)
 	    {
@@ -1529,12 +1530,11 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 	      sync_object->read_ok = FALSE;
 	      UNLOCK_WORKER_SYNC_OBJECT(sync_object);
 	      state = ghttp_process(request);
+	      current_status = ghttp_get_status(request);
 	    }
 	  else
 	    UNLOCK_WORKER_SYNC_OBJECT(sync_object);
 
-	  current_status = ghttp_get_status(request);
-
 	  if (status_code == 0
 	      && (current_status.proc == ghttp_proc_response
 		  || (sock_fd > 0
@@ -1608,6 +1608,20 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 
 	  if (state == ghttp_not_done)
 	    {
+	      const char *tmp_header;
+	      if (prev_proc == ghttp_proc_response_hdrs
+		  && (tmp_header = ghttp_get_header(request,
+						http_hdr_Transfer_Encoding))
+		  && strcasecmp(tmp_header, "chunked") == 0)
+		{
+		  /* ɤlibghttpasync⡼ɤǤ
+		   * Transfer-Encoding: chunkedפϡޤȤ˼갷ʤ
+		   * ͡
+		   */
+		  ghttp_set_sync(request, ghttp_sync);
+		  read_ok = FALSE;
+		}
+
 	      if (read_ok)
 		ghttp_flush_response_buffer(request);
 	    }
