@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_network_broker.h,v 1.5 2003/11/25 18:20:44 fuyu Exp $
+ * $Id: ochusha_network_broker.h,v 1.6 2003/12/14 16:10:28 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_NETWORK_BROKER_H_
@@ -128,6 +128,9 @@ typedef struct _OchushaNetworkBrokerBufferStatus
 GType ochusha_network_broker_get_type(void);
 OchushaNetworkBroker *ochusha_network_broker_new(OchushaConfig *config);
 
+void ochusha_network_broker_output_log(OchushaNetworkBroker *broker,
+				       const gchar *message);
+
 OchushaAsyncBuffer *ochusha_network_broker_read_from_url(
 					OchushaNetworkBroker *broker,
 					const char *url,
