@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_2ch.c,v 1.38 2003/12/11 18:06:24 fuyu Exp $
+ * $Id: ochusha_thread_2ch.c,v 1.41 2003/12/15 17:16:44 fuyu Exp $
  */
 
 #include "config.h"
@@ -475,8 +475,9 @@ ochusha_thread_2ch_get_responses_source(OchushaBBSThread *thread,
 
   thread_2ch = OCHUSHA_THREAD_2CH(thread);
 
-  if (thread->flags
-      & (OCHUSHA_BBS_THREAD_DAT_DROPPED | OCHUSHA_BBS_THREAD_STOPPED))
+  if (thread->flags & OCHUSHA_BBS_THREAD_DAT_DROPPED
+      || ((thread->flags & OCHUSHA_BBS_THREAD_STOPPED)
+	  && thread->number_of_responses_read > 0))
     mode = OCHUSHA_NETWORK_BROKER_CACHE_ONLY;
 
   return ochusha_network_broker_read_from_url(broker,
@@ -928,7 +929,7 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 #if DEBUG_ASYNC_BUFFER_MOST
 		    fprintf(stderr, "ochusha_thread_2ch_parse_responses(): buffer has been terminated.\n");
 #endif
-		    break;
+		    goto terminated;
 		  }
 #if COUNT_FAKE_SIGNAL	/* ¸ */
 		wait_count++;
@@ -971,6 +972,7 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 	  }
       }
 
+  terminated:
     if (number == MAX_RESPONSE)
       thread->number_of_responses_read = i;
   }
@@ -1151,6 +1153,12 @@ ochusha_thread_2ch_post_response(OchushaBBSThread *thread,
   else
     {
 #if DEBUG_POST
+      char message[4096];
+      snprintf(message, 4096, "thread_2ch(%s)->date == NULL\n",
+	       thread->title);
+      ochusha_network_broker_output_log(broker, message);
+#endif
+#if DEBUG_POST_MOST
       fprintf(stderr, "thread_2ch->date == NULL!\n");
 #endif
       time = ochusha_utils_get_utc_time(thread_2ch->last_modified);
@@ -1206,7 +1214,7 @@ ochusha_thread_2ch_post_response(OchushaBBSThread *thread,
   return TRUE;
 
  error_exit:
-#if DEBUG_POST
+#if DEBUG_POST_MOST
   fprintf(stderr, "Error happen\n");
 #endif
 
