@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_jbbs.c,v 1.10 2003/12/12 21:42:40 fuyu Exp $
+ * $Id: ochusha_thread_jbbs.c,v 1.12 2003/12/14 19:30:00 fuyu Exp $
  */
 
 #include "config.h"
@@ -670,7 +670,7 @@ ochusha_thread_jbbs_parse_responses(OchushaBBSThread *thread,
 #if DEBUG_ASYNC_BUFFER_MOST
 		    fprintf(stderr, "ochusha_thread_jbbs_parse_responses(): buffer has been terminated.\n");
 #endif
-		    break;
+		    goto terminated;
 		  }
 	      } while (buffer->length == old_len && !buffer->fixed);
 	  }
@@ -705,6 +705,7 @@ ochusha_thread_jbbs_parse_responses(OchushaBBSThread *thread,
 	  }
       }
   }
+ terminated:
   ochusha_async_buffer_unlock(buffer);
 
   if (status->last_modified != NULL)
@@ -1616,7 +1617,7 @@ ochusha_thread_jbbs_fake_responses_source(OchushaThread2ch *thread_2ch,
       break;
     }
 
-#if DEBUG_NETWORK
+#if DEBUG_NETWORK_MOST
   fprintf(stderr, "cgi_url=\"%s\"\n", cgi_url);
 #endif
 
