@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_utils_2ch.c,v 1.21 2003/11/29 08:52:05 fuyu Exp $
+ * $Id: ochusha_utils_2ch.c,v 1.25 2003/12/14 19:48:15 fuyu Exp $
  */
 
 #include "config.h"
@@ -1050,20 +1050,83 @@ ochusha_utils_2ch_try_post(OchushaNetworkBroker *broker,
 		}
 	      else
 		{
-#if DEBUG_POST
+#if DEBUG_POST_MOST
 		  fprintf(stderr, "Set-Cookie: %s\n", post_status.set_cookie);
 		  fprintf(stderr, "Result-Body: %s\n", post_status.body);
 #endif
 		  post_result = FALSE;
 		}
+#if DEBUG_POST
+	      if (post_status.body != NULL)
+		{
+		  const char *encoding
+		    = ochusha_bulletin_board_get_response_character_encoding(board);
+		  iconv_helper *helper
+		    = ochusha_bulletin_board_get_response_iconv_helper(board);
+		  iconv_t converter = iconv_open("UTF-8", encoding);
+		  if (converter != (iconv_t)-1)
+		    {
+		      gchar *body_utf8 = convert_string(converter, helper,
+							post_status.body, -1);
+		      if (body_utf8 != NULL)
+			{
+			  ochusha_network_broker_output_log(broker,
+							    "Result-Body: ");
+			  ochusha_network_broker_output_log(broker, body_utf8);
+			  ochusha_network_broker_output_log(broker, "\n");
+			  G_FREE(body_utf8);
+			}
+		      else
+			{
+			  ochusha_network_broker_output_log(broker,
+							    "iconv_failed.\n");
+			}
+		      iconv_close(converter);
+		    }
+		  else
+		    {
+		      ochusha_network_broker_output_log(broker,
+							"iconv_open failed.\n");
+		    }
+		}
+#endif
 	    }
 	}
 #if DEBUG_POST
       else
 	{
-	  fprintf(stderr, "status_code = %d\n", post_status.status_code);
-	  fprintf(stderr, "Set-Cookie: %s\n", post_status.set_cookie);
-	  fprintf(stderr, "Result-Body: %s\n", post_status.body);
+	  if (post_status.body != NULL)
+	    {
+	      const char *encoding
+		= ochusha_bulletin_board_get_response_character_encoding(board);
+	      iconv_helper *helper
+		= ochusha_bulletin_board_get_response_iconv_helper(board);
+	      iconv_t converter = iconv_open("UTF-8", encoding);
+	      if (converter != (iconv_t)-1)
+		{
+		  gchar *body_utf8 = convert_string(converter, helper,
+						    post_status.body, -1);
+		  if (body_utf8 != NULL)
+		    {
+		      ochusha_network_broker_output_log(broker,
+							"Result-Body: ");
+		      ochusha_network_broker_output_log(broker, body_utf8);
+		      ochusha_network_broker_output_log(broker, "\n");
+		      G_FREE(body_utf8);
+		    }
+		  else
+		    {
+		      ochusha_network_broker_output_log(broker,
+							"iconv_failed.\n");
+		    }
+		  iconv_close(converter);
+		}
+	      else
+		{
+		  ochusha_network_broker_output_log(broker,
+						    "iconv_open failed.\n");
+		}
+	    }
 	}
 #endif
     }
