@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: utils.c,v 1.13 2003/11/23 22:39:35 fuyu Exp $
+ * $Id: utils.c,v 1.15 2003/11/30 16:43:56 fuyu Exp $
  */
 
 #define OCHUSHA_UTILS_IMPLEMENTATION
@@ -251,6 +251,27 @@ wipe_string(const gchar *string)
 }
 
 
+/*
+ * ochusha_utils_url_extract_scheme
+ *
+ * Ϳ줿ʸURLȤƲᤷschemeʬ֤
+ * ˼ԤˤNULL֤
+ */
+char *
+ochusha_utils_url_extract_scheme(const char *url)
+{
+  char *comma_pos;
+  g_return_val_if_fail(url != NULL, NULL);
+
+  comma_pos = strchr(url, ':');
+  if (comma_pos == NULL)
+    return NULL;
+
+  /*  */
+  return G_STRNDUP(url, comma_pos - url);
+}
+
+
 /*
  * ochusha_utils_url_extract_http_server
  *
@@ -477,6 +498,48 @@ ochusha_utils_get_utc_time(const char *date_string)
 }
 
 
+char *
+ochusha_utils_find_cgi_query_key(const char *src, CGIQueryKeyTuple *result)
+{
+  const char *name_pos = src;
+  char *tmp_pos;
+
+  if (src == NULL)
+    return NULL;
+
+  while ((tmp_pos = strpbrk(name_pos, "&=")) != NULL)
+    {
+      char *term;
+      if (*tmp_pos == '&')
+	{
+	  name_pos = tmp_pos + 1;
+	  continue;
+	}
+
+      if (result != NULL)
+	{
+	  result->name = name_pos;
+	  result->name_len = tmp_pos - name_pos;
+	}
+
+      term = strchr(tmp_pos + 1, '&');
+      if (term == NULL)
+	term = tmp_pos + strlen(tmp_pos);
+      /* λǡ*value_tail'&''\0' */
+
+      if (result != NULL)
+	{
+	  result->value = tmp_pos + 1;
+	  result->value_len = term - tmp_pos - 1;
+	}
+
+      return term;
+    }
+
+  return NULL;
+}
+
+
 /*
  * mkdir_p
  *
